#include <M5StickC.h>
#include <WiFi.h>

RTC_TimeTypeDef RTC_TimeStruct;
RTC_DateTypeDef RTC_DateStruct;

const char* ssid = "xxxxxxxxxxxxx";       //←変更箇所
const char* password = "yyyyyyyyyyyyyyy"; //←変更箇所
const char* ntpServer = "ntp.nict.jp";
const long gmtOffset_sec = 3600 * 9;
const int daylightOffset_sec = 0;

void setup() {
  // M5StickCを初期化します
  M5.begin();
  M5.Lcd.setRotation(3);
  M5.Lcd.fillScreen(BLACK);

  M5.Lcd.setTextSize(1);
  M5.Lcd.setCursor(40, 0, 2);
  M5.Lcd.println("CLOCK TEST");

  // Wi-Fi接続
  Serial.println("Connecting to " + String(ssid));
  WiFi.begin(ssid, password);
  int cnt = 0;
  // Wi-Fi接続が完了するまで待機します（5秒で接続できない場合は諦めます）
  while (WiFi.status() != WL_CONNECTED && cnt < 10) {
    delay(500);
    Serial.print(".");
    cnt++;
  }
  if (WiFi.status() == WL_CONNECTED) {
    Serial.println(" CONNECTED");
    //初期化、日時の取得
    configTime(gmtOffset_sec, daylightOffset_sec, ntpServer);
  }
  //日時を取得してRTCにセットします
  struct tm timeInfo;
  if (getLocalTime(&timeInfo)) {
    // Set RTC time
    RTC_TimeTypeDef TimeStruct;
    TimeStruct.Hours = timeInfo.tm_hour;
    TimeStruct.Minutes = timeInfo.tm_min;
    TimeStruct.Seconds = timeInfo.tm_sec;
    M5.Rtc.SetTime(&TimeStruct);

    RTC_DateTypeDef DateStruct;
    DateStruct.WeekDay = timeInfo.tm_wday;
    DateStruct.Month = timeInfo.tm_mon + 1;
    DateStruct.Date = timeInfo.tm_mday;
    DateStruct.Year = timeInfo.tm_year + 1900;
    M5.Rtc.SetData(&DateStruct);
  }

  // Wi-Fi接続を切断します
  WiFi.disconnect(true);
  WiFi.mode(WIFI_OFF);
}

void loop() {
  // 0.5秒毎に画面に表示する日時を更新します
  M5.Rtc.GetTime(&RTC_TimeStruct);
  M5.Rtc.GetData(&RTC_DateStruct);
  M5.Lcd.setCursor(0, 15);
  M5.Lcd.printf("Data: %04d/%02d/%02d\n", RTC_DateStruct.Year, RTC_DateStruct.Month, RTC_DateStruct.Date);
  M5.Lcd.printf("Week: %d\n", RTC_DateStruct.WeekDay);
  M5.Lcd.printf("Time: %02d : %02d : %02d\n", RTC_TimeStruct.Hours, RTC_TimeStruct.Minutes, RTC_TimeStruct.Seconds);
  delay(500);
}
