#include "Adafruit_Sensor.h"
#include "UNIT_ENV.h"
#include <Adafruit_BMP280.h>
#include <M5Stack.h>
#include <WebServer.h>
SHT3X sht30;
Adafruit_BMP280 bmp;
QMP6988 qmp6988;

float tmp = 0.0;
float hum = 0.0;
float pressure = 0.0;

const char* ssid = "XXXXXXXXXXXXXXX"; //←変更箇所
const char* password = "YYYYYYYYYYYYYYY"; //←変更箇所
WebServer server(80); // Webサーバーを80番ポートで待ち受け

//コンテンツ内容を作成し、クライアントに送信する関数
void handleRoot() {
  String body = "\tENV2 UNIT TEST on Web\n";
  body += "Temp : ";
  body += tmp;
  body += " C\n";
  body += "Humidity : ";
  body += hum;
  body += " %\n";
  body += "Pressure : ";
  body += pressure / 100;
  body += " hPa\n";
  server.send(200, "text/plain", body);
}

//クライアントから存在しないリソースに対してアクセスがあった場合に404を送信する関数
void handleNotFound(){
  server.send(404, "text/plain", "File Not Found\n\n");
}

void setup() {
  // M5Stackを初期化します
  M5.begin();
  Wire.begin();
  qmp6988.init();

      // WiFi接続
      WiFi.begin(ssid, password);
  Serial.println("");
  // WiFi接続完了するまで待機します
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("Connected!");

  M5.Lcd.setTextSize(2);

  // M5Stackの画面にIPアドレスを表示します
  M5.Lcd.print("Connected to ");
  M5.Lcd.println(ssid);
  M5.Lcd.print("IP : ");
  M5.Lcd.println(WiFi.localIP());

  // Webサーバーのルートリソースへのアクセスに対する挙動を設定します
  server.on("/", handleRoot);
  //存在しないリソースへのアクセスに対する挙動を設定します
  server.onNotFound(handleNotFound);
  // Webサーバーを開始します
  server.begin();
  Serial.println("HTTP server started");

  // GroveポートにBME280センサーが接続されていない、または認識できない場合にエラーを表示します
  while (!bme.begin(0x76)) {
    Serial.println("Could not find a valid BMP280 sensor, check wiring!");
    M5.Lcd.println("Could not find a valid BMP280 sensor, check wiring!");
  }
}

void loop() {
  //気圧を取得します
  if (!bmp.begin(0x76)) {              // ENV2用気圧センサーの初期化
    pressure = qmp6988.calcPressure(); // ENV3から気圧を取得
  } else {
    pressure = bmp.readPressure(); // ENV2から気圧を取得
  }
  //温度と湿度を取得します
  if (sht30.get() == 0) {
    tmp = sht30.cTemp;
    hum = sht30.humidity;
  }

  // Webサーバーとして動作を継続
  server.handleClient();
  // 100ミリ秒待機します
  delay(100);
}
