#include "Adafruit_Sensor.h"
#include "UNIT_ENV.h"
#include <Adafruit_BMP280.h>
#include <Ambient.h>
#include <M5Stack.h>

SHT3X sht30;
Adafruit_BMP280 bmp;
QMP6988 qmp6988;

float tmp = 0.0;
float hum = 0.0;
float pressure = 0.0;

unsigned int channelId = 12345; // AmbientのチャネルID
const char* writeKey = "ZZZZZZZZZZZZZZZ"; // 変更箇所

const char* ssid = "XXXXXXXXXXXXXXX"; // 変更箇所
const char* password = “YYYYYYYYYYYYYYY"; // 変更箇所
Ambient ambient; // Ambientオブジェクトを定義
WiFiClient client;

void setup() {
  // M5Stackを初期化します
  M5.begin();
  Wire.begin();
  qmp6988.init();

  // WiFiに接続します
  WiFi.begin(ssid, password);
  Serial.println("");

  // WiFi接続完了するまで待機します
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("Connected!");

  M5.Lcd.setTextSize(2);

  ambient.begin(channelId, writeKey, &client); // チャネルIDとライトキーを指定してAmbientの初期化
}

void loop() {
  //気圧を取得します
  if (!bmp.begin(0x76)) {              // ENV2用気圧センサーの初期化
    pressure = qmp6988.calcPressure(); // ENV3センサーから気圧を取得
  } else {
    pressure = bmp.readPressure(); // ENV2センサーから気圧を取得
  }
  //温度と湿度を取得します
  if (sht30.get() == 0) {
    tmp = sht30.cTemp;
    hum = sht30.humidity;
  }

  M5.Lcd.setCursor(0, 0);
  M5.Lcd.setTextColor(WHITE, BLACK);

  M5.Lcd.printf("Temperature: %2.1f C \n", tmp);
  M5.Lcd.printf("Humidity : %2.0f %% \n", hum);
  M5.Lcd.printf("Pressure : %2.0f hPa \n", pressure / 100);

  // センサー値をセットしてAmbientに送信します
  ambient.set(1, tmp);
  ambient.set(2, hum);
  ambient.set(3, pressure / 100);
  ambient.send();

  // 30秒待機します（ambientの制限が1日3000件の為）
  delay(1000 * 30);
}
