#include <M5StickC.h>
#include <WiFi.h>
#include <esp_now.h>

#define CHANNEL
uint8_t slaveMAC[] = {0x01, 0x02, 0x03, 0x04, 0x05, 0x06}; //←変更箇所

float accX = 0.0F;
float accY = 0.0F;
float accZ = 0.0F;

//送信時に実行される関数です
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? " ...Success" : " ...Fail");
}

//子機(Slave)にデータを送信する関数です
void sendData(String payload) {
  // String型をuint8_t*型に変換します
  const uint8_t* p = reinterpret_cast<const uint8_t*>(payload.c_str());

  Serial.print("Sending: ");
  Serial.print(payload);
  //データを送信します
  esp_err_t result = esp_now_send(slaveMAC, p, sizeof(payload));
}

void setup() {
  // M5StickCを初期化します
  M5.begin();
  M5.IMU.Init();

  M5.Lcd.setRotation(3);
  M5.Lcd.setTextSize(1);

  // WiFiモードをSTAモードにします
  WiFi.mode(WIFI_STA);
  // ESP-NOWを初期化できているか確認します
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }

  // ESP-NOWでデータ送信する際のコールバック関数を登録する関数です
  esp_now_register_send_cb(OnDataSent);
  // ESP-NOWのpeer情報を定義します。
  esp_now_peer_info_t peerInfo;
  // slaveのMACアドレスをセットします。
  memcpy(peerInfo.peer_addr, slaveMAC, 6);
  // peerのチャネル情報の設定
  peerInfo.channel = CHANNEL;
  // peerの暗号化有無の設定
  peerInfo.encrypt = false;

  // Slaveと接続できたことを確認します
  if (esp_now_add_peer(&peerInfo) != ESP_OK) {
    Serial.println("Failed to add peer");
    return;
  }
}

void loop() {
  M5.IMU.getAccelData(&accX, &accY, &accZ);
  Serial.print("accX: "); Serial.println(accX);
  Serial.print("accY: "); Serial.println(accY);
  Serial.print("accZ: "); Serial.println(accZ);

  // M5StickCを傾けた方向によって、送信する数値を代入します。
  unsigned int rot = 1; //1:left 2:right 3:front or back
  if (accX > 0.4) {
    rot = 1;
  } else if (abs(accX) > 0.4) {
    rot = 2;
  } else if (accY < 0.6) {
    rot = 3;
  } else {
    rot = 0;
  }

  // Slaveにデータを送信する関数です
  sendData(String(rot));

  //液晶に"MaaMaa"という文字を表示します。
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.setTextSize(3);
  M5.Lcd.println("MaaMaa");

  // 100ミリ秒待機します
  delay(100);
}
