#include <M5Stack.h>
#include <WiFi.h>
#include <esp_now.h>

int state = -1;

//データを受信したときに実行される関数
void OnDataRecv(const uint8_t *mac_addr, const uint8_t *payload, int data_len) {
  Serial.print("Received Data: ");
  //受信したデータをString型に変換
  String msg = String((char *)payload);
  Serial.println(msg);
  M5.Lcd.setCursor(0, 0);
  M5.Lcd.setTextSize(4);

  //マスターのM5StickCが前に傾いている場合の表示
  if(msg.equals("3")) {
    if (state != 3){
      M5.Lcd.fillScreen(CYAN);
    }
    state = 3;
    M5.Lcd.setTextColor(WHITE, CYAN);
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print("Ottotto");
    //マスターのM5StickCが左右に傾いている場合の表示
  } else if(msg.equals("1") || msg.equals("2")) {
    if (state != 2){
      M5.Lcd.fillScreen(MAGENTA);
    }
    state = 2;
    M5.Lcd.setTextColor(WHITE, MAGENTA);
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print("Koboreru");
    //マスターのM5StickCが直立している場合の表示
  } else {
    if (state != 0){
      M5.Lcd.fillScreen(BLACK);
    }
    state = 0;
    M5.Lcd.setTextColor(WHITE, BLACK);
    M5.Lcd.setCursor(0, 0);
    M5.Lcd.print("SakeKure");
  }
}

void setup() {
  // M5Stackを初期化
  M5.begin();
  M5.Lcd.setTextSize(2);

  // WiFiをSTAモードで開始
  WiFi.mode(WIFI_STA);
  //液晶画面にMACアドレスを表示
  M5.Lcd.print("STA MAC: ");
  M5.Lcd.println(WiFi.macAddress());
  // WiFiを切断します。
  WiFi.disconnect();
  // ESP-NOWの初期化に失敗したら終了
  if (esp_now_init() != ESP_OK) {
    Serial.println("ESP-Now Init Failed....");
    return;
  }

  //データ受信時のコールバック関数を登録
  esp_now_register_recv_cb(OnDataRecv);
}

void loop() {
}
