// M5StickCの場合
#ifdef ARDUINO_M5Stick_C
#include <M5StickC.h>
// M5Stack Basicの場合
#else
#include <M5Stack.h>
#endif
#include <PubSubClient.h>
#include <WiFi.h>

const char* ssid = "XXXXXXXXXXXXXXX";      //←変更箇所
const char* password = "YYYYYYYYYYYYYYYY"; //←変更箇所
// MQTTの接続先(Beebotte)のURLを指定
const char *endpoint = "mqtt.beebotte.com";
// MQTTのポート番号を指定
const int port = 1883;
// Beebotteのチャネルトークンを指定
const char* channelToken = "token_ZZZZZZZZZZ"; //←変更箇所
//メッセージを知らせるトピックを指定
char *pubTopic = "m5/button";
//メッセージを待つトピックを指定
char *subTopic = "m5/button";

WiFiClient espClient;
PubSubClient client(espClient);

long lastReconnectAttempt = 0;
const char chars[] = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ 1234567890";
char id[17];

// MQTTのクライアントID用としてランダムIDを生成
const char *generateID() {
  randomSeed(analogRead(0));
  int i = 0;
  for(i = 0; i < sizeof(id) - 1; i++) {
    id[i] = chars[random(sizeof(chars))];
  }
  id[sizeof(id) - 1] = '\0';
  Serial.print("clientid: ");
  Serial.println(String(id));

  return id;
}

//コールバック用の関数
void callback(char* topic, byte* payload, unsigned int length) {
  Serial.print("Message arrived ["); //トピック名を出力
  Serial.print(topic);
  Serial.print("] ");

  payload[length] = '\0'; //受信メッセージをString型に変換
  String msg = String((char*) payload);
  Serial.println(msg);

  M5.Lcd.setCursor(0, 0); //カーソル位置をx=0 y=0で初期化
  //受信したメッセージの内容で分岐
  if (msg == "1") {
    M5.Lcd.fillScreen(RED); //液晶を赤色にし、"red"という文字を表示
    M5.Lcd.print("red");
  } else if (msg == "2") {
    M5.Lcd.fillScreen(GREEN); //液晶を緑色にし、"green"という文字を表示
    M5.Lcd.print("green");
  } else if (msg == "3") {
    M5.Lcd.fillScreen(BLUE); //液晶を青色にし、"blue"という文字を表示
    M5.Lcd.print("blue");
  }
}

//切断時に再接続する
boolean reconnect() {
  //再接続を試行
  if (client.connect(generateID(), channelToken, "")) {
    //接続が完了したらpublish
    client.publish(pubTopic, "hello from m5stack");
    //サブスクライブする
    client.subscribe(subTopic);

    Serial.println("Connected to Beebotte MQTT");
    M5.Lcd.println("Connected to Beebotte MQTT");
  }
  return client.connected();
}

void setup() {
  // M5StackまたはM5StickCを初期化
  M5.begin();

// M5StickCの場合
#if defined(ARDUINO_M5Stick_C)
  M5.Lcd.setRotation(3);
  M5.Lcd.setTextSize(1);
#else
  // M5Stackの場合
  M5.Lcd.setTextSize(2);
#endif

  Serial.print("Connecting to "); // Wi-Fi接続
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) { // Wi-Fi接続完了するまで待機
    delay(500);
    Serial.print(".");
  }
  Serial.println("WiFi Connected!");

  client.setServer(endpoint, port);
  client.setCallback(callback);
}

void loop() {
  M5.update();

  //ボタンA（左のボタン）が押されたとき
  if (M5.BtnA.wasReleased()) {
    client.publish(pubTopic, "1");
  //ボタンB（中央のボタン）が押されたとき
  } else if (M5.BtnB.wasReleased()) {
    client.publish(pubTopic, "2");
  }

// M5Stack Basicのみ
#ifndef ARDUINO_M5Stick_C
  //ボタンC（中央のボタン）が押されたとき
  if (M5.BtnC.wasReleased()) {
    client.publish(pubTopic, "3");
  }
#endif

  //接続が切れてしまった場合に再接続を試行
  if (!client.connected()) {
    long now = millis();
    if (now - lastReconnectAttempt > 5000) {
      lastReconnectAttempt = now;
      //再接続を試行
      if (reconnect()) {
        lastReconnectAttempt = 0;
      }
    }
  } else {
    //接続できている場合
    client.loop();
  }
}
